Stan Math Library: stan/math/prim/scal/fun/value_of_rec.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

value_of_rec.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_VALUE_OF_REC_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_VALUE_OF_REC_HPP
3
4 namespace stan {
5
6 namespace math {
7
23 template <typename T>
24 inline double value_of_rec(const T x) {
25 return static_cast<double>(x);
26 }
27
39 template <>
40 inline double value_of_rec<double>(const double x) {
41 return x;
42 }
43
44 }
45 }
46
47 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::value_of_rec
double value_of_rec(const fvar< T > &v)
Return the value of the specified variable.
Definition: value_of_rec.hpp:21
stan::math::value_of_rec< double >
double value_of_rec< double >(const double x)
Return the specified argument.
Definition: value_of_rec.hpp:40

[ Stan Home Page ] © 2011–2016, Stan Development Team.